import { Component, Input } from '@angular/core';
import { AppPage, AppPageState } from '@app/shared/pages/base-page.class';
import { RxState } from '@rx-angular/state';
import { Promise } from '@rx-angular/cdk/zone-less/browser';
import { TranslateService } from '@ngx-translate/core';
import { environment } from '@environments/environment';
import { ModalController } from '@ionic/angular';
import { Router } from '@angular/router';

export interface AboutModalState extends AppPageState {}

@Component({
  selector: 'app-about',
  templateUrl: './about.modal.html',
  styleUrls: ['./about.modal.css'],
  providers: [RxState],
})
export class AboutModal extends AppPage<AboutModalState> {
  protected readonly environment = environment;

  @Input() showToolbar = true;
  version: string;

  constructor(
    protected translate: TranslateService,
    protected viewCtrl: ModalController,
    protected router: Router
  ) {
    super({ name: 'about-modal' });
    this.version = environment.version;
  }

  protected ngOnLoad(): Promise<Partial<AboutModalState>> {
    return Promise.resolve(undefined);
  }

  cancel() {
    this.viewCtrl.dismiss();
  }

  goToHelpPage() {
    this.viewCtrl.dismiss();
    this.router.navigateByUrl('/help', {
      replaceUrl: true,
    });
  }

  isUpdateAvailable() {
    return this.environment.version !== this.version; //TODO: need more information about the current version and remote version
  }
}
