import { Environment } from './environment.class';
import { StorageDrivers } from '@app/shared/services/storage/storage.utils';

// eslint-disable-next-line @typescript-eslint/no-var-requires
const pkg = require('../../package.json');

export const environment = <Environment>{
  name: pkg.name as string,
  version: pkg.version as string,
  production: true,

  useHash: false,
  defaultLocale: 'fr',

  // About
  officialUrl: 'https://www.cesium.app',
  sourceUrl: 'https://git.duniter.org/clients/cesium-grp/cesium',
  reportIssueUrl: 'https://git.duniter.org/clients/cesium-grp/cesium/-/issues/new',
  forumUrl: 'https://forum.monnaie-libre.fr',

  graphql: {
    fetchPolicy: 'cache-first',
    watchFetchPolicy: 'cache-and-network',
    persistCache: false, // TODO test enabled
    fetchSize: 20,
  },

  // Storage
  storage: {
    name: 'cesium2',
    driverOrder: [StorageDrivers.IndexedDB, StorageDrivers.WebSQL, StorageDrivers.LocalStorage],
  },

  keyring: {
    ss58Format: 42, // dev
  },

  feed: {
    jsonFeed: {
      fr: ['https://forum.monnaie-libre.fr/t/actu-generale-la-1-bouge/31318.json'],
    },
    maxContentLength: 1300,
    maxAgeInMonths: 3,
    maxCount: 1,
  },
  defaultPeers: [
    /* Local endpoint */
    //'ws://127.0.0.1:9944',
    /* GDev endpoints */
    // 'wss://vit.fdn.org/ws',
    //'wss://1000i100.fr/ws',
    'wss://gdev.coinduf.eu/ws',
    'wss://gdev.pini.fr/ws',
    'wss://gdev.cgeek.fr/ws',
    'wss://gdev.p2p.legal/ws',
    'wss://archive-rpc.gdev.brussels.ovh/ws',
    'wss://archive-rpc.gdev.de.brussels.ovh/ws',
    'wss://gdev.p2p.legal/ws',
  ],

  defaultIndexers: [
    /* Local endpoint */
    //'http://localhost:8080/v1/graphql',
    /* GDev endpoints */
    'https://squid.gdev.coinduf.eu/v1beta1/relay',
    // 'https://gdev-squid.axiom-team.fr/graphql',
    'https://gdev-squid.axiom-team.fr/v1beta1/relay',
  ],

  defaultPods: [
    /* Local endpoint */
    // 'http://localhost:8081/v1/graphql'
    /* GDev endpoints */
    'https://datapod.coinduf.eu/v1/graphql',
    'https://datapod.gyroi.de:443/v1/graphql',
  ],

  defaultIfpsGateways: [
    /* Local endpoint */
    // 'http://localhost:8080'
    /* GDev endpoints */
    'https://pagu.re',
  ],

  defaultDistanceFileUrls: [
    /* Distance file Urls */
    'https://files.coinduf.eu/distance_precompute/latest_distance.json',
  ],
};
